#!/bin/bash


#  slackbuild script for xpenguins
# Author: Mark Tucker
# Created: Nov 30, 2004
# Changes:
#        Nov 30, 2004 - initial creation
#

#
#----------------------------------------------------------------------
umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="xpenguins-2.2.tar.gz"
pkgname="xpenguins"
pkgver="2.2"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package


#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source

echo Unpacking extra themes
tar -xzf $srcdir/xpenguins_themes-1.0.tar.gz
chown -R root.root $workdir/themes

cd $builddir
#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts="--prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var"
run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...

echo Installing extra themes...
cp -rav $workdir/themes/* $target/usr/share/xpenguins/themes/

# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
        |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver
$pkgname:
$pkgname: Ever wanted cute little penguins walking along the tops of your 
$pkgname: windows? Ever wanted to send an army of cute little penguins to 
$pkgname: invade the screen of someone else on your network? Probably not, but 
$pkgname: why not try this program out anyway - it's free (licensed under 
$pkgname: the GNU GPL). 
$pkgname: 
$pkgname: http://xpenguins.seul.org
$pkgname: 
$pkgname: Packaged by Mark Tucker for $slackver
END

# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit
